powered by
Find parameters for Beta prior based on prior mean and one quantile
find_beta_parms( mean, quantile, left_tail_prob, plot_results = TRUE, search_bounds = c(0.001, 100) )
Vector of beta shape parameters
numeric between 0 and 1 giving the prior mean
numeric between 0 and 1 giving the quantile lying at left_tail_prob
numeric between 0 and 1 giving the prior probability of theta being less than or equal to quantile
logical. Should the resulting inverse gamma distribution be plotted?
bounds with which to search. Sometimes you need to adjust this to get a good solution.
find_beta_parms(2/5,0.68,0.9) 2/ (2 + 3) qbeta(0.9,2,3)
Run the code above in your browser using DataLab